@@ -80,6 +80,11 @@ public:
     DoReplacement = true;
   }
 
+  void setPreserveRoutine(const std::string &Str) {
+    PreserveRoutine = Str;
+    DoPreserveRoutine = true;
+  }
+
   void setReferenceValue(const std::string &Str) {
     ReferenceValue = Str;
     CheckReference = true;
@@ -156,6 +161,10 @@ private:
 
   std::string Replacement;
 
+  bool DoPreserveRoutine;
+
+  std::string PreserveRoutine;
+
   bool CheckReference;
 
   std::string ReferenceValue;
