@@ -5,6 +5,7 @@ import tempfile
 
 from cvise.passes.abstract import AbstractPass, PassResult
 
+
 class BlankPass(AbstractPass):
     def check_prerequisites(self):
         return True
@@ -21,15 +22,15 @@ class BlankPass(AbstractPass):
     @staticmethod
     def __transform(test_case, pattern):
         tmp = os.path.dirname(test_case)
-        with tempfile.NamedTemporaryFile(mode="w+", delete=False, dir=tmp) as tmp_file:
-            with open(test_case, "r") as in_file:
+        with tempfile.NamedTemporaryFile(mode='w+', delete=False, dir=tmp) as tmp_file:
+            with open(test_case, 'r') as in_file:
                 matched = False
 
-                for l in in_file:
-                    if re.match(pattern, l) is not None:
+                for line in in_file:
+                    if re.match(pattern, line) is not None:
                         matched = True
                     else:
-                        tmp_file.write(l)
+                        tmp_file.write(line)
 
         if matched:
             shutil.move(tmp_file.name, test_case)
@@ -39,7 +40,7 @@ class BlankPass(AbstractPass):
         return matched
 
     def transform(self, test_case, state, process_event_notifier):
-        patterns = [r"^\s*$", r"^#"]
+        patterns = [r'^\s*$', r'^#']
 
         if state >= len(patterns):
             return (PassResult.STOP, state)
