@@ -5,9 +5,10 @@ import tempfile
 
 from cvise.passes.abstract import AbstractPass, PassResult
 
+
 class ClangPass(AbstractPass):
     def check_prerequisites(self):
-        return self.check_external_program("clang_delta")
+        return self.check_external_program('clang_delta')
 
     def new(self, test_case, _=None):
         return 1
@@ -20,13 +21,13 @@ class ClangPass(AbstractPass):
 
     def transform(self, test_case, state, process_event_notifier):
         tmp = os.path.dirname(test_case)
-        with tempfile.NamedTemporaryFile(mode="w", delete=False, dir=tmp) as tmp_file:
-            args = [self.external_programs["clang_delta"], "--transformation={}".format(self.arg), "--counter={}".format(state)]
+        with tempfile.NamedTemporaryFile(mode='w', delete=False, dir=tmp) as tmp_file:
+            args = [self.external_programs['clang_delta'], '--transformation={}'.format(self.arg), '--counter={}'.format(state)]
             if self.clang_delta_std:
                 args.append('--std={}'.format(self.clang_delta_std))
             cmd = args + [test_case]
 
-            logging.debug(" ".join(cmd))
+            logging.debug(' '.join(cmd))
 
             stdout, stderr, returncode = process_event_notifier.run_process(cmd)
             if returncode == 0:
