@@ -30,7 +30,8 @@ class ClangBinarySearchPass(AbstractPass):
         self.clang_delta_std = best
 
     def new(self, test_case, _=None):
-        self.detect_best_standard(test_case)
+        if not self.clang_delta_std:
+            self.detect_best_standard(test_case)
         return BinaryState.create(self.count_instances(test_case))
 
     def advance(self, test_case, state):
@@ -47,6 +48,8 @@ class ClangBinarySearchPass(AbstractPass):
         args = [self.external_programs['clang_delta'], '--query-instances={}'.format(self.arg)]
         if self.clang_delta_std:
             args.append('--std={}'.format(self.clang_delta_std))
+        if self.clang_delta_preserve_routine:
+            args.append(f'--preserve-routine="{self.clang_delta_preserve_routine}"')
         cmd = args + [test_case]
 
         try:
@@ -83,6 +86,8 @@ class ClangBinarySearchPass(AbstractPass):
                     '--warn-on-counter-out-of-bounds', '--report-instances-count']
             if self.clang_delta_std:
                 args.append('--std={}'.format(self.clang_delta_std))
+            if self.clang_delta_preserve_routine:
+                args.append(f'--preserve-routine="{self.clang_delta_preserve_routine}"')
             cmd = [self.external_programs['clang_delta']] + args + [test_case]
             logging.debug(' '.join(cmd))
 
