@@ -4,9 +4,10 @@ import tempfile
 
 from cvise.passes.abstract import AbstractPass, PassResult
 
+
 class ClexPass(AbstractPass):
     def check_prerequisites(self):
-        return self.check_external_program("clex")
+        return self.check_external_program('clex')
 
     def new(self, test_case, _=None):
         return 0
@@ -19,8 +20,8 @@ class ClexPass(AbstractPass):
 
     def transform(self, test_case, state, process_event_notifier):
         tmp = os.path.dirname(test_case)
-        with tempfile.NamedTemporaryFile(mode="w", delete=False, dir=tmp) as tmp_file:
-            cmd = [self.external_programs["clex"], str(self.arg), str(state), test_case]
+        with tempfile.NamedTemporaryFile(mode='w', delete=False, dir=tmp) as tmp_file:
+            cmd = [self.external_programs['clex'], str(self.arg), str(state), test_case]
             stdout, stderr, returncode = process_event_notifier.run_process(cmd)
             if returncode == 51:
                 tmp_file.write(stdout)
