@@ -5,6 +5,7 @@ import tempfile
 
 from cvise.passes.abstract import AbstractPass, PassResult
 
+
 class IncludeIncludesPass(AbstractPass):
     def check_prerequisites(self):
         return True
@@ -19,21 +20,21 @@ class IncludeIncludesPass(AbstractPass):
         return state
 
     def transform(self, test_case, state, process_event_notifier):
-        with open(test_case, "r") as in_file:
+        with open(test_case, 'r') as in_file:
             tmp = os.path.dirname(test_case)
-            with tempfile.NamedTemporaryFile(mode="w+", delete=False, dir=tmp) as tmp_file:
+            with tempfile.NamedTemporaryFile(mode='w+', delete=False, dir=tmp) as tmp_file:
                 includes = 0
                 matched = False
 
                 for line in in_file:
-                    include_match = re.match(r'\s*#\s*include\s*"(.*?)"', line)
+                    include_match = re.match(r"\s*#\s*include\s*'(.*?)'", line)
 
                     if include_match is not None:
                         includes += 1
 
                         if includes == state:
                             try:
-                                with open(include_match.group(1), "r") as inc_file:
+                                with open(include_match.group(1), 'r') as inc_file:
                                     matched = True
                                     tmp_file.write(inc_file.read())
                                     # Go to next include
